Module cache

Module cache 

Cache that only works with iterator-like structures. This file shouldn’t have a single instace of the term mut (other than this one lol).

Structs

Cache
Cache that works with iterator-like structures. Note that all operations are const since there are no user-facing mutations.

Traits

Cached
Pipe the output of an IntoIterator to make a Reiterator.

Functions

cached
Create a Cache from anything that can be turned into an Iterator.