Cache

Struct Cache 

pub struct Cache<I: Iterator> { /* private fields */ }
Cache that works with iterator-like structures. Note that all operations are const since there are no user-facing mutations.

Implementations

Source

impl<I: Iterator> Cache<I>

pub fn new<II: IntoIterator<IntoIter = I>>(into_iter: II) -> Self

Initialize a new empty cache.

pub fn is_empty(&self) -> bool

Whether this cache holds any cached elements.

pub fn get(&mut self, index: usize) -> Option<&I::Item>

If not already cached, repeatedly call next until we either reach index or next returns None. Immutably borrow this entire Cache for the duration of your returned reference.