Function reiterator::clone_value
source · pub fn clone_value<A: Clone>(indexed: Indexed<'_, A>) -> AExpand description
Clone and return the value from an Indexed item. Consumes its argument: written with .map(value) in mind.
pub fn clone_value<A: Clone>(indexed: Indexed<'_, A>) -> AClone and return the value from an Indexed item. Consumes its argument: written with .map(value) in mind.