Function reiterator::copy_value
source · pub const fn copy_value<A: Copy>(indexed: Indexed<'_, A>) -> AExpand description
Copy and return the value from an Indexed item. Consumes its argument: written with .map(value) in mind.
pub const fn copy_value<A: Copy>(indexed: Indexed<'_, A>) -> ACopy and return the value from an Indexed item. Consumes its argument: written with .map(value) in mind.